@@ -69,7 +69,6 @@ private:
     QAction *quitAction = nullptr;
     // The help menu
     QAction *aboutViewAction = nullptr;
-    QAction *aboutModuleAction = nullptr;
     KActionMenu *helpActionMenu = nullptr;
     // The configuration
     KConfigDialog *configDialog = nullptr;
@@ -81,7 +80,7 @@ private:
     MenuItem *rootModule = nullptr;
     MenuItem *homeModule = nullptr;
     MenuItem *lostFound = nullptr;
-    KService::List categories;
+    QStringList categories;
     KService::List modules;
     // The about dialog
     KAboutApplicationDialog *aboutDialog = nullptr;
